GCP saving
==========

GCP saving package is implemented for deploying a function that you can invoke for stopping, deleting or starting each ... instance.

The goal is to implement this package for each GCP service can stop, delete and start its instances.

It is part of the `educational repositories <https://github.com/pandle/materials>`_ to learn how to write stardard code and common uses of the TDD.

Prerequisites
#############

You can use `Serverless framework <https://www.serverless.com/framework/docs/providers/google/guide/installation/>`_ for deploying the function:
if you want to use the guide below, you have to install Serverless framework before.

If you want to use another GCP tool, you can see the repository `gcp-tool-comparison <https://github.com/bilardi/gcp-tool-comparison>`_ before to implement your version.

Installation
############

Coming soon.

Change Log
##########

See `CHANGELOG.md <https://github.com/bilardi/gcp-saving/CHANGELOG.md>`_ for details.

License
#######

This package is released under the MIT license.  See `LICENSE <https://github.com/bilardi/gcp-saving/LICENSE>`_ for details.
